==> beetl-3.0.7.RELEASE-sources.jar: org/beetl/core/cache/ProgramCacheFactory.java <==
/*
 [The "BSD license"]
 Copyright (c) 2011-2019  闲大赋 (李家智)
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
 3. The name of the author may not be used to endorse or promote products
     derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.beetl.core.cache;

import org.beetl.core.fun.ObjectUtil;

/**
 * 存储Program的缓存，默认是采用{@link LocalCache},可以通过设置
 * {@link Cache} 属性来设置新的缓存对象
 * @author joelli
 *
 */
public class ProgramCacheFactory
{
	/**
	 * 缓存实现类的类名
	 */
	public static String CACHE = "org.beetl.core.cache.LocalCache";

	public static Cache defaulCache()
	{
		
		ClassLoader loader = Thread.currentThread().getContextClassLoader();
		if(loader==null) {
			loader = ProgramCacheFactory.class.getClassLoader();
		}
		return (Cache) ObjectUtil.instance(CACHE,loader);

	}
}

==> beetl-3.1.8.RELEASE-sources.jar: org/beetl/core/cache/ProgramCacheFactory.java <==
/*
 [The "BSD license"]
 Copyright (c) 2011-2019  闲大赋 (李家智)
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
 2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
 3. The name of the author may not be used to endorse or promote products
     derived from this software without specific prior written permission.

 THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.beetl.core.cache;

import org.beetl.core.fun.ObjectUtil;

/**
 * 存储Program的缓存，默认是采用{@link LocalCache},可以通过设置
 * {@link Cache} 属性来设置新的缓存对象
 * @author joelli
 *
 */
public class ProgramCacheFactory
{
	/**
	 * 缓存实现类的类名
	 */
	public static String CACHE = "org.beetl.core.cache.LocalCache";

	public static Cache defaulCache()
	{
		
		ClassLoader loader = Thread.currentThread().getContextClassLoader();
		if(loader==null) {
			loader = ProgramCacheFactory.class.getClassLoader();
		}
		try{
			return (Cache) ObjectUtil.instance(CACHE,loader);
		}catch(Exception ex){
			System.out.println("load "+CACHE+ " by "+loader+" error ,instead local");
			return new  LocalCache();
		}


	}
}
